#!/usr/bin/env python3
# -*- coding: utf-8 -*-
from typing import List
from src.utils import bcolors


class DayOne:
    def import_expense_report(self, loc: str) -> List[int]:
        data = open(loc).read().split()
        expense = [int(x) for x in data]
        return expense

    def find_two_factors(self, L: List[int]) -> float:
        """
        given a list, find the two nums that sum to 2020
        what is their product?
        """
        list_shift = [2020-x for x in L]
        factors = list(set(L) & set(list_shift))
        product = factors[0] * factors[1]
        return product

    def find_three_factors(self, L: List[int]) -> float:
        """
        given a list, find the three nums that sum to 2020
        what is their product?
        """
        list_shift = [2020-x for x in L]
        twice_shift = [[x-y for y in L] for x in list_shift]
        flat_list = [item for sublist in twice_shift for item in sublist]
        factors = list(set(flat_list) & set(L))
        product = factors[0] * factors[1] * factors[2]
        return product

    def answers(self, L: List[int]):
        two_factors = self.find_two_factors(L)
        three_factors = self.find_three_factors(L)
        print(f"{bcolors.OKBLUE}Day One.{bcolors.ENDC}")
        print("The two numbers together are {}".format(str(two_factors)))
        print("The three numbers together are {}".format(str(three_factors)))



import sys

__version__ = '0.2.0'

def direc_dumper():
    if (len(sys.argv) == 1) or (len(sys.argv) > 2):
        raise ValueError("You need to give 1 argument to the command line, this will be the name of the new directory")

    directory = str(sys.argv[1]).strip()
    from roci.main import creator as create
    create(directory)



import os
from pkg_resources import resource_filename
from distutils.dir_util import copy_tree

def creator(directory):
    print("Hello, let's try create a nice new directory for you!")
    if os.path.exists(directory):
        print("this directory exists, better choose a different name")
    else:
        print("perfect, lets create a new directory called ", directory)
        os.makedirs(directory)
        path = resource_filename("roci", "structure/")
        copy_tree(path, directory)
        print("Done!")
        


#!/usr/bin/env python3
# -*- coding: utf-8 -*-
import src.day01 as d1


def main():
    expenses = d1.DayOne().import_expense_report("src/data/input.txt")
    d1.DayOne().answers(expenses)


if __name__ == '__main__':
    main()



# -*- coding: utf-8 -*-
from distutils.core import setup

packages = \
['roci', 'roci.structure.src', 'roci.structure.tests']

package_data = \
{'': ['*'],
 'roci': ['structure/*', 'structure/.github/workflows/*', 'structure/docs/*'],
 'roci.structure.src': ['data/*'],
 'roci.structure.tests': ['.pytest_cache/*', '.pytest_cache/v/cache/*']}

entry_points = \
{'console_scripts': ['roci = roci:direc_dumper']}

setup_kwargs = {
    'name': 'roci',
    'version': '0.2.0',
    'description': 'no longer a work horse',
    'long_description': None,
    'author': 'Andrew Blance',
    'author_email': 'andrewblance@live.co.uk',
    'url': None,
    'packages': packages,
    'package_data': package_data,
    'entry_points': entry_points,
    'python_requires': '>=3.6,<4.0',
}


setup(**setup_kwargs)



#!/usr/bin/env python3
# -*- coding: utf-8 -*-
"""
Created on Tue Dec  1 17:56:17 2020

@author: andrewblance
"""

from os.path import dirname, basename, isfile
import glob

modules = glob.glob(dirname(__file__)+"/*.py")
__all__ = [basename(f)[:-3] for f in modules if isfile(f)]



#!/usr/bin/env python3
# -*- coding: utf-8 -*-
"""
Created on Tue Dec  1 16:58:55 2020

@author: andrewblance
"""

import src.day01 as d1


class TestDayOne:
    def test_two_factors(self):
        L = [1, 5, 20000, 1009, 1011, 2]
        factors = d1.DayOne().find_two_factors(L)
        assert factors == 1020099

    def test_three_factors(self):
        L = [1, 5, 20000, 1009, 1010]
        factors = d1.DayOne().find_three_factors(L)
        assert factors == 1019090
